@@ -20,8 +20,8 @@ from .proc import command_ex
 from .proc import shell_script
 from .proc import start_process
 
-__version__ = "0.2.4"
-_name = 'k3proc'
+__version__ = "0.2.5"
+__name__ = 'k3proc'
 
 __all__ = [
     'CalledProcessError',
